@@ -5,13 +5,17 @@
 #' @importFrom purrr accumulate discard every keep map map2 map2_chr
 #'   map2_dbl map2_df map2_int map2_lgl map_at map_chr map_dbl map_df
 #'   map_if map_int map_lgl pmap pmap_chr pmap_dbl pmap_df pmap_int
-#'   pmap_lgl reduce some transpose
+#'   pmap_lgl imap reduce some transpose
 #' @importFrom dplyr tbl_vars
 #' @importFrom utils type.convert
 #' @importFrom lifecycle deprecated
 #' @useDynLib tidyr, .registration = TRUE
 "_PACKAGE"
 
+on_load(local_use_cli())
+
+the <- new_environment()
+
 globalVariables(c(".", "name", "value"))
 
 #' @importFrom tibble tribble
