@@ -23,10 +23,10 @@ test_that("missings are filled correctly", {
   out <- fill(df, x, .direction = "up")
   expect_equal(out$x, c(1, 1, 2, 2, NA, NA))
 
-  out <- fill(df, x, .direction = 'downup')
+  out <- fill(df, x, .direction = "downup")
   expect_equal(out$x, c(1, 1, 1, 2, 2, 2))
 
-  out <- fill(df, x, .direction = 'updown')
+  out <- fill(df, x, .direction = "updown")
   expect_equal(out$x, c(1, 1, 2, 2, 2, 2))
 })
 
@@ -108,6 +108,21 @@ test_that("fill preserves attributes", {
 
 test_that("fill respects grouping", {
   df <- tibble(x = c(1, 1, 2), y = c(1, NA, NA))
-  out <- df %>% dplyr::group_by(x) %>% fill(y)
+  out <- df %>%
+    dplyr::group_by(x) %>%
+    fill(y)
   expect_equal(out$y, c(1, 1, NA))
 })
+
+test_that("works when there is a column named `.direction` in the data (#1319)", {
+  df <- tibble(x = c(1, NA, 2), .direction = 1:3)
+  expect_error(out <- fill(df, x), NA)
+  expect_identical(out$x, c(1, 1, 2))
+})
+
+test_that("validates its inputs", {
+  df <- tibble(x = c(1, NA, 2))
+  expect_snapshot(error = TRUE, {
+    df %>% fill(x, .direction = "foo")
+  })
+})
